OiRA

Help

1. Preparació
2. Implicació
3. Identificació + Avaluació
4. Pla d'acció
   1. 1.1.1 Slips, trips and falls are not prevented.
   2. 1.1.2 Collisions, bumps, and jamming are not prevented.
   3. 1.1.4 Exposure to noise is neither prevented nor controlled.
   4. 1.1.6 Exposure to biological substances is neither prevented nor controlled
   5. Ω.1 The entrance floor is often wet
   6. Title of the first custom risk
   7. This is another custom risk added by the user
   - Actuar
5. Informe
6. Grau d’emplenament 9%

# Commercial guarding, Leicester

Un cop identificats els riscos, cal implementar un pla d'acció per gestionar els riscos. Per eliminar o reduir els riscos, cal determinar les mesures de prevenció i protecció que cal adoptar.

Aquests són alguns dels aspectes que cal tenir en compte per a aquest pas:

1. Es pot evitar el risc? Es pot eliminar del tot? Per exemple, es pot aconseguir:
   - preguntant-se si la tasca o feina és necessària
   - eliminant el perill
2. Si hi ha certs riscos que no es poden evitar, com es poden reduir fins a un nivell en què no amenacin la salut i la seguretat de les persones que hi estan exposades?

Un cop ha decidit com eliminar o reduir un risc determinat, pot descriure les accions concretes que es requereixen per aconseguir-ho. També hauria d'incloure informació sobre el nivell de competència i/o altres requisits necessaris per a l'eficàcia d'aquestes accions.

Crear pla d'acció

Scroll to top
Back

## action-plan-landing.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More